/*
 * Copyright (c) 2015 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
*/

#include <Eina.h>
#include <app_debug.h>

#include "datamgr.h"
#include "defs.h"

struct datamgr *datamgr_init(struct data_class *dclass, const char *view_id)
{
	struct datamgr *dm;

	if (!view_id || !dclass) {
		_ERR("Invalid argument");
		return NULL;
	}

	dm = calloc(1, sizeof(*dm));
	if (!dm) {
		_ERR("failed to calloc dm");
		return NULL;
	}

	dm->view_id = view_id;
	dm->dclass = dclass;

	if (!dm->dclass->init(dm)) {
		_ERR("failed to initialize dclass");
		free(dm);
		return NULL;
	}

	return dm;
}

void datamgr_fini(struct datamgr *dm)
{
	if (!dm) {
		_ERR("Invalid argument");
		return;
	}

	dm->dclass->fini(dm);

	free(dm);
}

Eina_List *datamgr_get_items(struct datamgr *dm)
{
	if (!dm || !dm->dclass) {
		_ERR("Invalid argument");
		return NULL;
	}

	if (!dm->dclass->get_items)
		return NULL;

	return dm->dclass->get_items(dm);
}

int datamgr_select_item(struct datamgr *dm, struct datamgr_item *di)
{
	if (!dm || !dm->dclass || !di) {
		_ERR("Invalid argument");
		return ITEM_SELECT_ERROR_INVALID_PARAMETER;
	}

	if (!dm->dclass->select)
		return ITEM_SELECT_ERROR_NONE;

	return dm->dclass->select(di);
}

void datamgr_clear_item(struct datamgr *dm)
{
	if (!dm || !dm->dclass) {
		_ERR("Invalid argument");
		return;
	}

	if (!dm->dclass->clear)
		return;

	dm->dclass->clear(dm);
}

int datamgr_add_item(struct datamgr *dm, const char *title, const char *icon,
		const char *parameter)
{
	if (!dm || !dm->dclass) {
		_ERR("Invalid argument");
		return USER_ADD_ERROR_INVALID_OPERATION;
	}

	if (!dm->dclass->add)
		return USER_ADD_ERROR_INVALID_OPERATION;

	return dm->dclass->add(dm, title, icon, parameter);
}
